@@ -75,28 +75,4 @@ class BaseRequest(RequestBase):
         return self.request(self.Method.Post, path, data_fmt)
 
 
-if __name__ == '__main__':
-    from simple_priority_queue import SimplePriorityQueue
-    from concurrent.futures import ThreadPoolExecutor
-
-    queue = SimplePriorityQueue()
-    worker = ThreadPoolExecutor(10)
-
-
-    class DemoRequest(BaseRequest):
-        base = 'http://www.baidu.com'
-
-
-    def request(q: SimplePriorityQueue):
-        for req in q:
-            if req:
-                req.init()
-                res = req.get_()
-                print(res.text[:100])
-            else:
-                time.sleep(1)
-
-
-    task = worker.submit(request, queue)
-    queue.push_pri(DemoRequest(path='/'))
-    resp = task.result()
+__all__ = ('RequestBase', 'BaseRequest')
